translate.storage.utx.UtxUnit

Package translate :: Package storage :: Module utx :: Class UtxUnit |
[hide private]
[frames] | no frames]

# Class UtxUnit

source code

A UTX dictionary unit

Instance Methods | [hide private]
__init__(self, source=None) Constructs a TranslationUnit containing the given source string. | source code
getdict(self) Get the dictionary of values for a UTX line | source code
setdict(self, newdict) Set the dictionary of values for a UTX line | source code
_get_field(self, key) | source code
_set_field(self, key, newvalue) | source code
__str__(self) Converts to a string representation that can be parsed back using `parsestring()`. | source code
istranslated(self) Indicates whether this unit is translated. | source code
Inherited from `base.TranslationUnit`: `__eq__`, `get_state_id`, `get_state_n`, `getcontext`, `getid`, `getunits`, `hasplural`, `infer_state`, `isblank`, `isfuzzy`, `isheader`, `isobsolete`, `isreview`, `istranslatable`, `makeobsolete`, `markfuzzy`, `markreviewneeded`, `merge`, `multistring_to_rich`, `set_state_n`, `setcontext`, `setid`, `unit_iter` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`
Source
getsource(self) | source code
setsource(self, newsource) Sets the source string to the given value. | source code
Inherited from `base.TranslationUnit`: `getsourcelanguage` Inherited from `base.TranslationUnit` (private): `_get_rich_source`, `_set_rich_source`
Target
gettarget(self) | source code
settarget(self, newtarget) Sets the target string to the given value. | source code
settargetlang(self, newlang) | source code
Inherited from `base.TranslationUnit`: `gettargetlanguage`, `gettargetlen` Inherited from `base.TranslationUnit` (private): `_get_rich_target`, `_set_rich_target`
Notes
getnotes(self, origin=None) Returns all notes about this unit. | source code
addnote(self, text, origin=None, position="append") Adds a note (comment). | source code
removenotes(self) Remove all the translator's notes. | source code
Locations
Inherited from `base.TranslationUnit`: `addlocation`, `addlocations`, `getlocations`
Errors
Inherited from `base.TranslationUnit`: `adderror`, `geterrors`

Class Methods | [hide private]
Inherited from `base.TranslationUnit`: `buildfromunit`, `rich_to_multistring`

Class Variables | [hide private]
| dict = `property(getdict, setdict)`
Inherited from `base.TranslationUnit`: `STATE`, `S_EMPTY`, `S_FINAL`, `S_NEEDS_REVIEW`, `S_NEEDS_WORK`, `S_OBSOLETE`, `S_REJECTED`, `S_UNREVIEWED`, `rich_parsers` Inherited from `base.TranslationUnit` (private): `_state_n`, `_store`
Source
| source = `property(getsource, setsource)`
Inherited from `base.TranslationUnit` (private): `_rich_source`, `_source`
Target
| target = `property(gettarget, settarget)`
| targetlang = `property(None, settargetlang)`
Inherited from `base.TranslationUnit` (private): `_rich_target`, `_target`
Notes
Inherited from `base.TranslationUnit`: `notes`

Properties | [hide private]
Inherited from `base.TranslationUnit`: `rid`, `xid` Inherited from `object`: `__class__`
Source
Inherited from `base.TranslationUnit`: `rich_source`
Target
Inherited from `base.TranslationUnit`: `rich_target`

Method Details | [hide private]

### __init__(self, source=None) (Constructor) | source code
Constructs a TranslationUnit containing the given source string. Overrides: object.__init__ (inherited documentation)

### setdict(self, newdict) | source code
Set the dictionary of values for a UTX line Parameters: `newdict` (Dict) - a new dictionary with UTX line elements

### getnotes(self, origin=None) | source code
Returns all notes about this unit. It will probably be freeform text or something reasonable that can be synthesised by the format. It should not include location comments (see getlocations()). Overrides: base.TranslationUnit.getnotes (inherited documentation)

### addnote(self, text, origin=None, position="append") | source code
Adds a note (comment). Parameters: `text` - Usually just a sentence or two. `origin` - Specifies who/where the comment comes from. Origin can be one of the following text strings: 'translator' 'developer', 'programmer', 'source code' (synonyms) Overrides: base.TranslationUnit.addnote (inherited documentation)

### removenotes(self) | source code
Remove all the translator's notes. Overrides: base.TranslationUnit.removenotes (inherited documentation)

### setsource(self, newsource) | source code
Sets the source string to the given value. Overrides: base.TranslationUnit.setsource (inherited documentation)

### settarget(self, newtarget) | source code
Sets the target string to the given value. Overrides: base.TranslationUnit.settarget (inherited documentation)

### __str__(self) (Informal representation operator) | source code
Converts to a string representation that can be parsed back using `parsestring()`. Overrides: object.__str__ (inherited documentation)

### istranslated(self) | source code
Indicates whether this unit is translated. This should be used rather than deducing it from .target, to ensure that other classes can implement more functionality (as XLIFF does). Overrides: base.TranslationUnit.istranslated (inherited documentation)